Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Kafka ¶
type Kafka struct {
Workers int `json:"workers"`
Topic string `json:"topic"`
Brokers []string `json:"brokers"`
GroupID string `json:"group_id"`
MinBytes int `json:"min_bytes"`
MaxBytes int `json:"max_bytes"`
MaxWait time.Duration `json:"max_wait"`
// contains filtered or unexported fields
}
Kafka implements fusion stream using the Kafka system as the backend with support for consumer groups. This implementation uses manual commit based on the Ack function to ensure at-least once delivery. Downstream consumers must take care of idempotency.
Click to show internal directories.
Click to hide internal directories.